Struct
MalcontentAppFilterBuilder
since: 0.2.0
Description [src]
struct MctAppFilterBuilder {
/* No available fields */
}
A stack-allocated mutable structure used to build an
MctAppFilter instance.
Use mct_app_filter_builder_init(), various method
calls to set properties of the app filter, and then
mct_app_filter_builder_end(), to construct an
MctAppFilter.
Available since: 0.2.0
Instance methods
mct_app_filter_builder_blocklist_content_type
Add content_type to the blocklist of content types in the filter under construction.
since: 0.4.0
mct_app_filter_builder_blocklist_flatpak_ref
Add app_ref to the blocklist of flatpak refs in the filter under construction.
since: 0.2.0
mct_app_filter_builder_blocklist_path
Add path to the blocklist of app paths in the filter under construction.
since: 0.2.0
mct_app_filter_builder_copy
Copy the given builder to a newly-allocated
MctAppFilterBuilder on the heap.
since: 0.2.0
mct_app_filter_builder_end
Finish constructing an MctAppFilter with the given builder,
and return it.
since: 0.2.0
mct_app_filter_builder_free
Free an MctAppFilterBuilder originally allocated using
mct_app_filter_builder_new().
since: 0.2.0
mct_app_filter_builder_init
Initialise the given builder so it can be used to construct a new
MctAppFilter.
since: 0.2.0
mct_app_filter_builder_set_allow_system_installation
Set whether the user is allowed to install to the flatpak system repository.
since: 0.2.0
mct_app_filter_builder_set_allow_user_installation
Set whether the user is allowed to install to their flatpak user repository.
since: 0.2.0
mct_app_filter_builder_set_oars_value
Set the OARS value for the given oars_section, indicating the intensity of
content covered by that section which the user is allowed to see (inclusive).
since: 0.2.0